==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebRatingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebRatingDescription } from "./WebRatingDescription";
/**
 * @hidden
 */
var WebRatingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRatingDescriptionMetadata, _super);
    function WebRatingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRatingDescriptionMetadata.b = function (a) {
        if (WebRatingDescriptionMetadata.a == null) {
            WebRatingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRatingDescriptionMetadata.c(WebRatingDescriptionMetadata.a);
        }
        if (a.j(WebRatingDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRatingDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebRatingDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Rating");
        a.item("__tagNameWC", "String:igc-rating");
        a.item("Max", "Number:double");
        a.item("Step", "Number:double");
        a.item("Name", "String");
        a.item("Label", "String");
        a.item("ValueFormat", "String");
        a.item("Value", "Number:double");
        a.item("Disabled", "Boolean");
        a.item("HoverPreview", "Boolean");
        a.item("Readonly", "Boolean");
        a.item("Single", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ChangeRef", "EventRef::change");
        a.item("HoverRef", "EventRef::hover");
    };
    WebRatingDescriptionMetadata.d = function (a) {
        WebRatingDescriptionMetadata.b(a);
        a.aa("WebRating", function () { return new WebRatingDescription(); });
        a.z("WebRating", WebRatingDescriptionMetadata.a);
    };
    WebRatingDescriptionMetadata.$t = markType(WebRatingDescriptionMetadata, 'WebRatingDescriptionMetadata');
    WebRatingDescriptionMetadata.a = null;
    return WebRatingDescriptionMetadata;
}(Base));
export { WebRatingDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRatingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebRatingDescription } from "./WebRatingDescription";
/**
 * @hidden
 */
var WebRatingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRatingDescriptionMetadata, _super);
    function WebRatingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRatingDescriptionMetadata.b = function (a) {
        if (WebRatingDescriptionMetadata.a == null) {
            WebRatingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRatingDescriptionMetadata.c(WebRatingDescriptionMetadata.a);
        }
        if (a.k(WebRatingDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRatingDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebRatingDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Rating");
        a.item("__tagNameWC", "String:igc-rating");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Max", "Number:double");
        a.item("Step", "Number:double");
        a.item("Name", "String");
        a.item("Label", "String");
        a.item("ValueFormat", "String");
        a.item("Value", "Number:double");
        a.item("Disabled", "Boolean");
        a.item("HoverPreview", "Boolean");
        a.item("Readonly", "Boolean");
        a.item("Single", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ChangeRef", "EventRef::change");
        a.item("HoverRef", "EventRef::hover");
    };
    WebRatingDescriptionMetadata.d = function (a) {
        WebRatingDescriptionMetadata.b(a);
        a.ac("WebRating", function () { return new WebRatingDescription(); });
        a.ab("WebRating", WebRatingDescriptionMetadata.a);
    };
    WebRatingDescriptionMetadata.$t = markType(WebRatingDescriptionMetadata, 'WebRatingDescriptionMetadata');
    WebRatingDescriptionMetadata.a = null;
    return WebRatingDescriptionMetadata;
}(Base));
export { WebRatingDescriptionMetadata };
